OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "V souporabi  z drugimi",
    "Shared with you" : "V souporabi z vami",
    "Shared by link" : "V souporabi prek povezave",
    "Deleted shares" : "Izbrisane povezave za souporabo",
    "Shares" : "Souporaba",
    "Nothing shared with you yet" : "Datotek drugih uporabnikov še ni v souporabi",
    "Files and folders others share with you will show up here" : "Datoteke in mape, katerih souporabo z vami omogočijo drugi, bodo zbrane na tem mestu.",
    "Nothing shared yet" : "Souporabe datotek še niste omogočili",
    "Files and folders you share will show up here" : "Datoteke in mape, ki ste jih označili za souporabo z drugimi, bodo zbrane na tem mestu.",
    "No shared links" : "Ni povezav za souporabo",
    "Files and folders you share by link will show up here" : "Datoteke in mape, ki ste jih označili za souporabo prek povezave, bodo zbrane na tem mestu.",
    "No deleted shares" : "Ni izbrisanih povezav za souporabo.",
    "No shares" : "Brez souporabe",
    "Shares will show up here" : "Predmeti v souporabi bodo prikazani na tem mestu.",
    "Download" : "Prejmi",
    "Delete" : "Izbriši",
    "You can upload into this folder" : "V to mapo je dovoljeno pošiljati datoteke",
    "Invalid server URL" : "Neveljaven URL strežnika",
    "No expiration date set" : "Datum poteka ni določen",
    "Shared by" : "V souporabi z",
    "File shares" : "Datoteke v souporabi",
    "Downloaded via public link" : "Prejeto prek javne povezave",
    "{file} downloaded via public link" : "Datoteka {file} je prejeta prek javne povezave",
    "Removed public link" : "Javno povezava je odstranjena",
    "Public link expired" : "Javna povezava je potekla",
    "You removed public link for {file}" : "Odstranite povezavo do datoteke {file}",
    "{user} accepted the remote share" : "Uporabnik {user} potrdi oddaljeno souporabo",
    "{user} accepted the remote share of {file}" : "Uporabnik {user} potrdi oddaljeno souporabo {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Datoteko oziroma mapo v souporabi prek elektronske pošte oziroma javne povezave je uporabnik <strong>prejel na svoj krajevni disk</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Datoteka ali mapa je bila dodana v souporabo prek <strong>drugega strežnika</strong>",
    "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je omogočena <strong>souporaba</strong>",
    "Wrong share ID, share doesn't exist" : "Napačen ID mesta uporabe; mesto ne obstaja!",
    "Could not delete share" : "Tega predmeta v souporabi ni mogoče izbrisati.",
    "Please specify a file or folder path" : "Določiti je treba datoteko ali pot do mape",
    "Wrong path, file/folder doesn't exist" : "Napačna pot; datoteka ali mapa ne obstaja",
    "Could not create share" : "Mesta souporabe ni mogoče ustvariti",
    "invalid permissions" : "neustrezna dovoljenja",
    "Please specify a valid user" : "Navesti je treba veljavnega uporabnika.",
    "Group sharing is disabled by the administrator" : "Skupinska souporaba je skrbniško onemogočena",
    "Please specify a valid group" : "Navesti je treba veljavno skupino",
    "Public link sharing is disabled by the administrator" : "Souporaba prek javne povezave je skrbniško onemogočena",
    "Public upload disabled by the administrator" : "Javno pošiljanje v oblak je skrbniško onemogočeno",
    "Public upload is only possible for publicly shared folders" : "Javno pošiljanje v oblak je mogoče le za mape v javni skupni rabi.",
    "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
    "Unknown share type" : "Neznana vrsta mesta souporabe",
    "Not a directory" : "Predmet ni mapa",
    "Could not lock path" : "Poti ni mogoče zakleniti",
    "Wrong or no update parameter given" : "Parameter posodobitve ni podan ali pa je navedena napačna vrednost",
    "Can't change permissions for public share links" : "Za javne povezave souporabe, spreminjanje dovoljenj ni mogoče.",
    "Direct link" : "Neposredna povezava",
    "Add to your Nextcloud" : "Dodaj v svoj Nextcloud",
    "Share API is disabled" : "Vmesnik API za souporabo je onemogočen",
    "Share" : "Souporaba",
    "Sharing" : "Souporaba",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Name" : "Ime",
    "Share time" : "Čas souporabe",
    "Expiration date" : "Datum preteka",
    "Sorry, this link doesn’t seem to work anymore." : "Povezava očitno ni več v uporabi.",
    "Reasons might be:" : "Vzrok je lahko:",
    "the item was removed" : "predmet je odstranjen,",
    "the link expired" : "povezava je pretekla,",
    "sharing is disabled" : "souporaba je onemogočena.",
    "For more info, please ask the person who sent this link." : "Za več podrobnosti stopite v stik s pošiljateljem te povezave.",
    "Download %s" : "Prejmi %s",
    "Upload files to %s" : "Pošlji datoteke v %s",
    "Select or drop files" : "Izberi ali povleci datoteke",
    "Uploading files…" : "Poteka pošiljanje datotek ...",
    "Uploaded files:" : "Poslane datoteke:",
    "could not delete share" : "mesta souporabe ni mogoče ustvariti"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
